@@ -1,11 +1,10 @@
 from kotti import get_settings
-from kotti import get_version
 from kotti.resources import DBSession
 from kotti.resources import Node
 from kotti.resources import Document
-from kotti.resources import Settings
 from kotti.security import get_principals
 from kotti.security import SITE_ACL
+from kotti.workflow import get_workflow
 
 
 def populate_users():
@@ -18,6 +17,7 @@ def populate_users():
             'groups': [u'role:admin'],
             }
 
+
 def populate():
     if DBSession.query(Node).count() == 0:
         root = Document(**_ROOT_ATTRS)
@@ -25,14 +25,15 @@ def populate():
         DBSession.add(root)
         root['about'] = Document(**_ABOUT_ATTRS)
 
-    if DBSession.query(Settings).count() == 0:
-        settings = Settings(data={'kotti.db_version': get_version()})
-        DBSession.add(settings)
+        wf = get_workflow(root)
+        if wf is not None:
+            DBSession.flush()  # Initializes workflow
+            wf.transition_to_state(root, None, u'public')
 
     populate_users()
 
 _ROOT_ATTRS = dict(
-    name=u'', # (at the time of writing) root must have empty name!
+    name=u'',  # (at the time of writing) root must have empty name!
     title=u'Welcome to Kotti',
     description=u'Congratulations! You have successfully installed Kotti.',
     body=u"""
@@ -56,14 +57,16 @@ _ROOT_ATTRS = dict(
   using a simple text file in your file system.
 </p>
 <p>
-  <a href="http://kotti.readthedocs.org/en/latest/configuration.html" class="btn btn-info">Configuration manual</a>
+  <a href="http://kotti.readthedocs.org/en/latest/configuration.html"
+     class="btn btn-info">Configuration manual</a>
 </p>
 <p>
   A number of add-ons allow you to extend the functionality of your
   Kotti site.
 </p>
 <p>
-  <a href="http://pypi.python.org/pypi?%3Aaction=search&amp;term=kotti&amp;submit=search" class="btn btn-info">Kotti add-ons</a>
+  <a href="http://pypi.python.org/pypi?%3Aaction=search&term=kotti"
+     class="btn btn-info">Kotti add-ons</a>
 </p>
 
 <h2>Develop</h2>
@@ -71,7 +74,8 @@ _ROOT_ATTRS = dict(
   Kotti aims to be easy and extensible.  Check out the developer manual.
 </p>
 <p>
-  <a href="http://kotti.readthedocs.org/en/latest/developer-manual.html" class="btn btn-info">Developer Manual</a>
+  <a href="http://kotti.readthedocs.org/en/latest/developer-manual.html"
+     class="btn btn-info">Developer Manual</a>
 </p>
 
 <h2>Documentation</h2>
@@ -80,7 +84,8 @@ _ROOT_ATTRS = dict(
   the manual for more information.
 </p>
 <p>
-  <a href="http://kotti.readthedocs.org/en/latest/" class="btn btn-info">Documentation</a>
+  <a href="http://kotti.readthedocs.org/en/latest/"
+     class="btn btn-info">Documentation</a>
 </p>
 """)
 
@@ -110,8 +115,8 @@ _ABOUT_ATTRS = dict(
   <em>Photo credit:</em> "Northern Lights Formation" by FlugKerl2.
   <a href="http://commons.wikimedia.org/wiki/File:Northern_Lights_Formation.jpg">
   Copyright info</a>.
-  Originally published in the 
-  <a href="http://en.wikipedia.org/wiki/Extra_EA-300"> Extra EA-300</a> 
+  Originally published in the
+  <a href="http://en.wikipedia.org/wiki/Extra_EA-300"> Extra EA-300</a>
   article.
 </small></p>
 """)
