@@ -8,15 +8,16 @@ from mock import patch
 from kotti.testing import DummyRequest
 from kotti.testing import UnitTestBase
 
+
 class TestFileViews(UnitTestBase):
     def setUp(self):
         from kotti.resources import File
-        self.file = File("file contents", u"myf\xfcle.png", u"image/png", 46578)
+        self.file = File("file contents", u"myf\xfcle.png", u"image/png")
 
     def _test_common_headers(self, headers):
         for name in ('Content-Disposition', 'Content-Length', 'Content-Type'):
             assert type(headers[name]) == str
-        assert headers["Content-Length"] == "46578"
+        assert headers["Content-Length"] == "13"
         assert headers["Content-Type"] == "image/png"
 
     def test_inline_view(self):
@@ -26,8 +27,8 @@ class TestFileViews(UnitTestBase):
 
         self._test_common_headers(headers)
         assert headers["Content-Disposition"] == 'inline;filename="myfle.png"'
-        assert res.app_iter == 'file contents'
-        
+        assert res.body == 'file contents'
+
     def test_attachment_view(self):
         from kotti.views.file import attachment_view
         res = attachment_view(self.file, None)
@@ -36,7 +37,8 @@ class TestFileViews(UnitTestBase):
         self._test_common_headers(headers)
         assert headers["Content-Disposition"] == (
             'attachment;filename="myfle.png"')
-        assert res.app_iter == 'file contents'
+        assert res.body == 'file contents'
+
 
 class TestEditFileFormView(TestCase):
     def make_one(self):
@@ -76,6 +78,7 @@ class TestEditFileFormView(TestCase):
         assert view.context.mimetype == u'image/png'
         assert view.context.size == 777
 
+
 class TestAddFileFormView(TestCase):
     def make_one(self):
         from kotti.views.file import AddFileFormView
@@ -120,11 +123,12 @@ class TestAddFileFormView(TestCase):
                 ),
             ))
 
+
 class TestFileUploadTempStore(TestCase):
     def make_one(self):
         from kotti.views.file import FileUploadTempStore
         return FileUploadTempStore(DummyRequest())
-    
+
     def test_keys(self):
         tmpstore = self.make_one()
         tmpstore.session['important'] = 3
