@@ -1,6 +1,7 @@
 from StringIO import StringIO
 from UserDict import DictMixin
 
+from colander import Invalid
 from colander import MappingSchema
 from colander import SchemaNode
 from colander import String
@@ -10,10 +11,15 @@ from deform.widget import FileUploadWidget
 from deform.widget import TextAreaWidget
 from pyramid.response import Response
 
+from kotti import get_settings
 from kotti.resources import File
-from kotti.views.edit import ContentSchema
-from kotti.views.util import EditFormView
-from kotti.views.util import AddFormView
+from kotti.util import _
+from kotti.views.form import (
+    ContentSchema,
+    EditFormView,
+    AddFormView,
+    )
+
 
 class FileUploadTempStore(DictMixin):
     def __init__(self, request):
@@ -40,30 +46,44 @@ class FileUploadTempStore(DictMixin):
     def preview_url(self, name):
         return None
 
+
 def inline_view(context, request, disposition='inline'):
     res = Response(
         headerlist=[
             ('Content-Disposition', '%s;filename="%s"' % (
                 disposition, context.filename.encode('ascii', 'ignore'))),
-            ('Content-Length', str(context.size)),
             ('Content-Type', str(context.mimetype)),
-            ],
-        app_iter=context.data,
+            ]
         )
-    
+    res.body = context.data
     return res
 
+
 def attachment_view(context, request):
     return inline_view(context, request, 'attachment')
 
+
+def validate_file_size_limit(node, value):
+    value['fp'].seek(0, 2)
+    size = value['fp'].tell()
+    value['fp'].seek(0)
+    max_size = get_settings()['kotti.max_file_size']
+    if size > int(max_size) * 1024 * 1024:
+        msg = _('Maximum file size: ${size}MB', mapping={'size': max_size})
+        raise Invalid(node, msg)
+
+
 class EditFileFormView(EditFormView):
     def schema_factory(self):
         tmpstore = FileUploadTempStore(self.request)
+
         class FileSchema(ContentSchema):
             file = SchemaNode(
                 FileData(),
+                title=_(u'File'),
                 missing=null,
                 widget=FileUploadWidget(tmpstore),
+                validator=validate_file_size_limit,
                 )
         return FileSchema()
 
@@ -77,24 +97,30 @@ class EditFileFormView(EditFormView):
             self.context.mimetype = appstruct['file']['mimetype']
             self.context.size = len(buf)
 
+
 class AddFileFormView(AddFormView):
-    item_type = u"file"
+    item_type = _(u"File")
+    item_class = File
 
     def schema_factory(self):
         tmpstore = FileUploadTempStore(self.request)
+
         class FileSchema(MappingSchema):
-            title = SchemaNode(String(), missing=u'')
+            title = SchemaNode(String(), title=_(u'Title'), missing=u'')
             description = SchemaNode(
                 String(),
+                title=_('Description'),
                 missing=u"",
                 widget=TextAreaWidget(cols=40, rows=5),
                 )
             file = SchemaNode(
                 FileData(),
+                title=_(u'File'),
                 widget=FileUploadWidget(tmpstore),
+                validator=validate_file_size_limit,
                 )
         return FileSchema()
-    
+
     def save_success(self, appstruct):
         if not appstruct['title']:
             appstruct['title'] = appstruct['file']['filename']
@@ -102,7 +128,7 @@ class AddFileFormView(AddFormView):
 
     def add(self, **appstruct):
         buf = appstruct['file']['fp'].read()
-        return File(
+        return self.item_class(
             title=appstruct['title'],
             description=appstruct['description'],
             data=buf,
@@ -111,6 +137,7 @@ class AddFileFormView(AddFormView):
             size=len(buf),
             )
 
+
 def includeme(config):
     config.add_view(
         inline_view,
